==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/containerservice/kotlin/inputs/ManagedClusterSecurityProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerservice.kotlin.inputs

import com.pulumi.azurenative.containerservice.inputs.ManagedClusterSecurityProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Security profile for the container service cluster.
 * @property azureKeyVaultKms Azure Key Vault [key management service](https://kubernetes.io/docs/tasks/administer-cluster/kms-provider/) settings for the security profile.
 * @property defender Microsoft Defender settings for the security profile.
 * @property imageCleaner Image Cleaner settings for the security profile.
 * @property workloadIdentity Workload identity settings for the security profile. Workload identity enables Kubernetes applications to access Azure cloud resources securely with Azure AD. See https://aka.ms/aks/wi for more details.
 */
public data class ManagedClusterSecurityProfileArgs(
    public val azureKeyVaultKms: Output<AzureKeyVaultKmsArgs>? = null,
    public val defender: Output<ManagedClusterSecurityProfileDefenderArgs>? = null,
    public val imageCleaner: Output<ManagedClusterSecurityProfileImageCleanerArgs>? = null,
    public val workloadIdentity: Output<ManagedClusterSecurityProfileWorkloadIdentityArgs>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.containerservice.inputs.ManagedClusterSecurityProfileArgs> {
    override fun toJava():
        com.pulumi.azurenative.containerservice.inputs.ManagedClusterSecurityProfileArgs =
        com.pulumi.azurenative.containerservice.inputs.ManagedClusterSecurityProfileArgs.builder()
            .azureKeyVaultKms(azureKeyVaultKms?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .defender(defender?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .imageCleaner(imageCleaner?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .workloadIdentity(
                workloadIdentity?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [ManagedClusterSecurityProfileArgs].
 */
@PulumiTagMarker
public class ManagedClusterSecurityProfileArgsBuilder internal constructor() {
    private var azureKeyVaultKms: Output<AzureKeyVaultKmsArgs>? = null

    private var defender: Output<ManagedClusterSecurityProfileDefenderArgs>? = null

    private var imageCleaner: Output<ManagedClusterSecurityProfileImageCleanerArgs>? = null

    private var workloadIdentity: Output<ManagedClusterSecurityProfileWorkloadIdentityArgs>? = null

    /**
     * @param value Azure Key Vault [key management service](https://kubernetes.io/docs/tasks/administer-cluster/kms-provider/) settings for the security profile.
     */
    @JvmName("igpmcdoxdmmiusac")
    public suspend fun azureKeyVaultKms(`value`: Output<AzureKeyVaultKmsArgs>) {
        this.azureKeyVaultKms = value
    }

    /**
     * @param value Microsoft Defender settings for the security profile.
     */
    @JvmName("hebrxpvptjvnetid")
    public suspend fun defender(`value`: Output<ManagedClusterSecurityProfileDefenderArgs>) {
        this.defender = value
    }

    /**
     * @param value Image Cleaner settings for the security profile.
     */
    @JvmName("ywyfxgepcdcxtdmu")
    public suspend fun imageCleaner(`value`: Output<ManagedClusterSecurityProfileImageCleanerArgs>) {
        this.imageCleaner = value
    }

    /**
     * @param value Workload identity settings for the security profile. Workload identity enables Kubernetes applications to access Azure cloud resources securely with Azure AD. See https://aka.ms/aks/wi for more details.
     */
    @JvmName("nkxifpgctdmcjoae")
    public suspend
    fun workloadIdentity(`value`: Output<ManagedClusterSecurityProfileWorkloadIdentityArgs>) {
        this.workloadIdentity = value
    }

    /**
     * @param value Azure Key Vault [key management service](https://kubernetes.io/docs/tasks/administer-cluster/kms-provider/) settings for the security profile.
     */
    @JvmName("pdulilyggjaojyyd")
    public suspend fun azureKeyVaultKms(`value`: AzureKeyVaultKmsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.azureKeyVaultKms = mapped
    }

    /**
     * @param argument Azure Key Vault [key management service](https://kubernetes.io/docs/tasks/administer-cluster/kms-provider/) settings for the security profile.
     */
    @JvmName("qcbyftqwehrqgqje")
    public suspend fun azureKeyVaultKms(argument: suspend AzureKeyVaultKmsArgsBuilder.() -> Unit) {
        val toBeMapped = AzureKeyVaultKmsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.azureKeyVaultKms = mapped
    }

    /**
     * @param value Microsoft Defender settings for the security profile.
     */
    @JvmName("imnvtuvdgsexwldq")
    public suspend fun defender(`value`: ManagedClusterSecurityProfileDefenderArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.defender = mapped
    }

    /**
     * @param argument Microsoft Defender settings for the security profile.
     */
    @JvmName("anfygwlpgdwxoims")
    public suspend
    fun defender(argument: suspend ManagedClusterSecurityProfileDefenderArgsBuilder.() -> Unit) {
        val toBeMapped = ManagedClusterSecurityProfileDefenderArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.defender = mapped
    }

    /**
     * @param value Image Cleaner settings for the security profile.
     */
    @JvmName("qhhbfbbqxeacnxeb")
    public suspend fun imageCleaner(`value`: ManagedClusterSecurityProfileImageCleanerArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.imageCleaner = mapped
    }

    /**
     * @param argument Image Cleaner settings for the security profile.
     */
    @JvmName("rnduibkotfyqjjsv")
    public suspend
    fun imageCleaner(argument: suspend ManagedClusterSecurityProfileImageCleanerArgsBuilder.() -> Unit) {
        val toBeMapped = ManagedClusterSecurityProfileImageCleanerArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.imageCleaner = mapped
    }

    /**
     * @param value Workload identity settings for the security profile. Workload identity enables Kubernetes applications to access Azure cloud resources securely with Azure AD. See https://aka.ms/aks/wi for more details.
     */
    @JvmName("uhrgoehavgpluqya")
    public suspend fun workloadIdentity(`value`: ManagedClusterSecurityProfileWorkloadIdentityArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.workloadIdentity = mapped
    }

    /**
     * @param argument Workload identity settings for the security profile. Workload identity enables Kubernetes applications to access Azure cloud resources securely with Azure AD. See https://aka.ms/aks/wi for more details.
     */
    @JvmName("aepyaunhfunxwcyb")
    public suspend
    fun workloadIdentity(argument: suspend ManagedClusterSecurityProfileWorkloadIdentityArgsBuilder.() -> Unit) {
        val toBeMapped = ManagedClusterSecurityProfileWorkloadIdentityArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.workloadIdentity = mapped
    }

    internal fun build(): ManagedClusterSecurityProfileArgs = ManagedClusterSecurityProfileArgs(
        azureKeyVaultKms = azureKeyVaultKms,
        defender = defender,
        imageCleaner = imageCleaner,
        workloadIdentity = workloadIdentity,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/containerservice/kotlin/inputs/ManagedClusterSecurityProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerservice.kotlin.inputs

import com.pulumi.azurenative.containerservice.inputs.ManagedClusterSecurityProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Security profile for the container service cluster.
 * @property azureKeyVaultKms Azure Key Vault [key management service](https://kubernetes.io/docs/tasks/administer-cluster/kms-provider/) settings for the security profile.
 * @property defender Microsoft Defender settings for the security profile.
 * @property imageCleaner Image Cleaner settings for the security profile.
 * @property workloadIdentity Workload identity settings for the security profile. Workload identity enables Kubernetes applications to access Azure cloud resources securely with Azure AD. See https://aka.ms/aks/wi for more details.
 */
public data class ManagedClusterSecurityProfileArgs(
    public val azureKeyVaultKms: Output<AzureKeyVaultKmsArgs>? = null,
    public val defender: Output<ManagedClusterSecurityProfileDefenderArgs>? = null,
    public val imageCleaner: Output<ManagedClusterSecurityProfileImageCleanerArgs>? = null,
    public val workloadIdentity: Output<ManagedClusterSecurityProfileWorkloadIdentityArgs>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.containerservice.inputs.ManagedClusterSecurityProfileArgs> {
    override fun toJava():
        com.pulumi.azurenative.containerservice.inputs.ManagedClusterSecurityProfileArgs =
        com.pulumi.azurenative.containerservice.inputs.ManagedClusterSecurityProfileArgs.builder()
            .azureKeyVaultKms(azureKeyVaultKms?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .defender(defender?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .imageCleaner(imageCleaner?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .workloadIdentity(
                workloadIdentity?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [ManagedClusterSecurityProfileArgs].
 */
@PulumiTagMarker
public class ManagedClusterSecurityProfileArgsBuilder internal constructor() {
    private var azureKeyVaultKms: Output<AzureKeyVaultKmsArgs>? = null

    private var defender: Output<ManagedClusterSecurityProfileDefenderArgs>? = null

    private var imageCleaner: Output<ManagedClusterSecurityProfileImageCleanerArgs>? = null

    private var workloadIdentity: Output<ManagedClusterSecurityProfileWorkloadIdentityArgs>? = null

    /**
     * @param value Azure Key Vault [key management service](https://kubernetes.io/docs/tasks/administer-cluster/kms-provider/) settings for the security profile.
     */
    @JvmName("icicefssisiepsga")
    public suspend fun azureKeyVaultKms(`value`: Output<AzureKeyVaultKmsArgs>) {
        this.azureKeyVaultKms = value
    }

    /**
     * @param value Microsoft Defender settings for the security profile.
     */
    @JvmName("yqmccefadlopcxwf")
    public suspend fun defender(`value`: Output<ManagedClusterSecurityProfileDefenderArgs>) {
        this.defender = value
    }

    /**
     * @param value Image Cleaner settings for the security profile.
     */
    @JvmName("btobyyhcscxiicjp")
    public suspend fun imageCleaner(`value`: Output<ManagedClusterSecurityProfileImageCleanerArgs>) {
        this.imageCleaner = value
    }

    /**
     * @param value Workload identity settings for the security profile. Workload identity enables Kubernetes applications to access Azure cloud resources securely with Azure AD. See https://aka.ms/aks/wi for more details.
     */
    @JvmName("yjusbfeicimnjvxd")
    public suspend
    fun workloadIdentity(`value`: Output<ManagedClusterSecurityProfileWorkloadIdentityArgs>) {
        this.workloadIdentity = value
    }

    /**
     * @param value Azure Key Vault [key management service](https://kubernetes.io/docs/tasks/administer-cluster/kms-provider/) settings for the security profile.
     */
    @JvmName("jwbyeddgvxdfkrwg")
    public suspend fun azureKeyVaultKms(`value`: AzureKeyVaultKmsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.azureKeyVaultKms = mapped
    }

    /**
     * @param argument Azure Key Vault [key management service](https://kubernetes.io/docs/tasks/administer-cluster/kms-provider/) settings for the security profile.
     */
    @JvmName("wjdipqjkdmqgekvl")
    public suspend fun azureKeyVaultKms(argument: suspend AzureKeyVaultKmsArgsBuilder.() -> Unit) {
        val toBeMapped = AzureKeyVaultKmsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.azureKeyVaultKms = mapped
    }

    /**
     * @param value Microsoft Defender settings for the security profile.
     */
    @JvmName("hgbcqhgshjgiojms")
    public suspend fun defender(`value`: ManagedClusterSecurityProfileDefenderArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.defender = mapped
    }

    /**
     * @param argument Microsoft Defender settings for the security profile.
     */
    @JvmName("rhwugirblleylgjw")
    public suspend
    fun defender(argument: suspend ManagedClusterSecurityProfileDefenderArgsBuilder.() -> Unit) {
        val toBeMapped = ManagedClusterSecurityProfileDefenderArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.defender = mapped
    }

    /**
     * @param value Image Cleaner settings for the security profile.
     */
    @JvmName("khgydygcmeiqtpop")
    public suspend fun imageCleaner(`value`: ManagedClusterSecurityProfileImageCleanerArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.imageCleaner = mapped
    }

    /**
     * @param argument Image Cleaner settings for the security profile.
     */
    @JvmName("bnpwrvduvjmoxjcr")
    public suspend
    fun imageCleaner(argument: suspend ManagedClusterSecurityProfileImageCleanerArgsBuilder.() -> Unit) {
        val toBeMapped = ManagedClusterSecurityProfileImageCleanerArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.imageCleaner = mapped
    }

    /**
     * @param value Workload identity settings for the security profile. Workload identity enables Kubernetes applications to access Azure cloud resources securely with Azure AD. See https://aka.ms/aks/wi for more details.
     */
    @JvmName("vbvdagpbphypkevm")
    public suspend fun workloadIdentity(`value`: ManagedClusterSecurityProfileWorkloadIdentityArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.workloadIdentity = mapped
    }

    /**
     * @param argument Workload identity settings for the security profile. Workload identity enables Kubernetes applications to access Azure cloud resources securely with Azure AD. See https://aka.ms/aks/wi for more details.
     */
    @JvmName("gdoflksndcfscepk")
    public suspend
    fun workloadIdentity(argument: suspend ManagedClusterSecurityProfileWorkloadIdentityArgsBuilder.() -> Unit) {
        val toBeMapped = ManagedClusterSecurityProfileWorkloadIdentityArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.workloadIdentity = mapped
    }

    internal fun build(): ManagedClusterSecurityProfileArgs = ManagedClusterSecurityProfileArgs(
        azureKeyVaultKms = azureKeyVaultKms,
        defender = defender,
        imageCleaner = imageCleaner,
        workloadIdentity = workloadIdentity,
    )
}
